﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace SteemaChartSampleApplication
{
    public partial class MainPage : UserControl
    {
        private double increment;
        private bool SetFormat;

        public MainPage()
        {
            InitializeComponent();
            increment = 1;
            SampleChart.Aspect.View3D = false;
            SampleChart.Axes.Left.Automatic = true;
            SampleChart.Axes.Left.MaximumRound = true;
            SampleChart.Axes.Left.Grid.Visible = false;
            SampleChart.Axes.Right.Grid.Visible = false;
            SetFormat = false;
        }

        private void DrawChart()
        {
            SampleChart.Series.Clear(true);

            Steema.TeeChart.Silverlight.Styles.Line  LineSeries1;

            LineSeries1 = new Steema.TeeChart.Silverlight.Styles.Line();  

            for (int i = 1; i <= 10; i++)
            {
                LineSeries1.Add(i,i * increment);
            }
            
            SampleChart.Series.Add(LineSeries1);
            SetFormat = true;
        }

        private void First_Click(object sender, RoutedEventArgs e)
        {
            increment = 0.5;
            DrawChart();
        }

        private void Second_Click(object sender, RoutedEventArgs e)
        {
            increment = 0.05;
            DrawChart();
        }

        private void Third_Click(object sender, RoutedEventArgs e)
        {
            increment = 0.005;
            DrawChart();
        }


        //Dettermines the Label format on the basis of Incremenental gap of Y Axis
        private string YAxisFormat(double Diff)
        {
            string sFormat;
            int i;

            if (Diff >= 1)
            {
                return "#,##0";
            }

            sFormat = "0.";
            for (i = 0; i <= 10; i++)
            {
                sFormat = sFormat + "0";
                if (Diff < 1 / Math.Pow(10, i) && Diff >= 1 / Math.Pow(10, i + 1))
                    break;
            }
            return sFormat;
        }

        private void SampleChart_AfterDraw(object sender, Steema.TeeChart.Silverlight.Drawing.Graphics3D g)
        {
            if (SetFormat)
            {
                SetFormat = false;
                SampleChart.Axes.Left.Labels.ValueFormat = YAxisFormat(SampleChart.Axes.Left.CalcIncrement);
                SampleChart.Axes.Draw();
            }

            string HexaColor = "#000000";

            SampleChart.Graphics3D.Pen.Color = 
                Color.FromArgb(
                     Convert.ToByte("FF", 16),
                     Convert.ToByte(HexaColor.Substring(1, 2), 16),
                     Convert.ToByte(HexaColor.Substring(3, 2), 16),
                     Convert.ToByte(HexaColor.Substring(5, 2), 16)
                     );

            if (SampleChart.Axes.Left.MinYValue < 0)
            {
                SampleChart.Graphics3D.Pen.Width = 1.5;
                SampleChart.Graphics3D.Line(new System.Windows.Point(SampleChart.Axes.Bottom.IStartPos, SampleChart.Axes.Left.CalcPosValue(0)), new System.Windows.Point(SampleChart.Axes.Bottom.IEndPos, SampleChart.Axes.Left.CalcPosValue(0)));
            }
           

        }

        private void TwoAxis_Click(object sender, RoutedEventArgs e)
        {
            increment = 1;
            SampleChart.Series.Clear(true);

            Steema.TeeChart.Silverlight.Styles.Line LeftSeries;
            LeftSeries = new Steema.TeeChart.Silverlight.Styles.Line();
            LeftSeries.VertAxis = Steema.TeeChart.Silverlight.Styles.VerticalAxis.Left;  

            Steema.TeeChart.Silverlight.Styles.Line RightSeries;
            RightSeries = new Steema.TeeChart.Silverlight.Styles.Line();
            RightSeries.VertAxis = Steema.TeeChart.Silverlight.Styles.VerticalAxis.Right;

            for (int i = 0; i <10; i++)
            {
                RightSeries.Add(i, i * increment);
            }

            LeftSeries.Title = "Left Series";

            for (int i = 0; i <5; i++)
            {
                LeftSeries.Add(i, i * increment);
                LeftSeries.Add(i, -(i * increment));
            }
            RightSeries.Title = "Right Series"; 

            SampleChart.Series.Add(LeftSeries);
            SampleChart.Series.Add(RightSeries);

            SetFormat = false;
        }
    }
}
